.. fastreid documentation master file, created by
   sphinx-quickstart on Sat Sep 21 13:46:45 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to fastreid's documentation!
======================================

.. toctree::
   :maxdepth: 2

   tutorials/index
   notes/index
   modules/index
